@@ -13,14 +13,24 @@ Created on 2012-03-07
 @author: mohanr
 """
 from datetime import datetime
+import io
 import logging
 import os
-import string
 
-import bencode
-from bencode import BTL
 import six
 
+from seedbox.torrent import bencode
+
+
+def _is_int(val):
+    ret_val = True
+    try:
+        int(val)
+    except ValueError:
+        ret_val = False
+
+    return ret_val
+
 
 class ParsingError(Exception):
     """ Error class representing errors that occur while parsing
@@ -71,7 +81,7 @@ class TorrentParser(object):
         INT_END = 'e'
 
         def __init__(self, torr_str):
-            self.torr_str = six.StringIO(torr_str)
+            self.torr_str = six.BytesIO(torr_str)
             self.curr_char = None
 
         def next_char(self):
@@ -80,12 +90,16 @@ class TorrentParser(object):
                 1. as return value,
                 2. as self.curr_char (useful in some circumstances)
             """
-            self.curr_char = self.torr_str.read(1)
+            self.curr_char = self.torr_str.read(1).decode(encoding='utf-8',
+                                                          errors='replace')
             return self.curr_char
 
         def step_back(self, position=-1, mode=1):
             """ Step back, by default, 1 position relative to the
             current position.
+
+            :param position: offset from current position
+            :param mode: current position
             """
             self.torr_str.seek(position, mode)
 
@@ -146,7 +160,7 @@ class TorrentParser(object):
             parsed_int = ''
             while True:
                 parsed_int_char = self.next_char()
-                if parsed_int_char not in string.digits:
+                if not _is_int(parsed_int_char):
                     if parsed_int_char != delimiter:
                         raise ParsingError(
                             'Invalid character %s found after parsing an \
@@ -162,6 +176,10 @@ class TorrentParser(object):
     def __init__(self, torrent_file_path):
         """
         Reads the torrent file and sets the content as an object attribute.
+        .. todo::
+
+            Investigate merging logic from custom parser into bencode code
+            base such that a single unit of code supports parsing.
 
         :param str torrent_file_path: Path to the torrent file to be parsed
         :raises IOError:    when a torrent_file_path does not exists
@@ -173,7 +191,7 @@ class TorrentParser(object):
         if not os.path.exists(torrent_file_path):
             raise IOError('No file found at %s'.format(torrent_file_path))
 
-        with open(torrent_file_path, 'rb') as handle:
+        with io.open(file=torrent_file_path, mode='rb') as handle:
             self.torrent_content = handle.read()
 
         # bencode is supremely more efficient parser of torrents but extremely
@@ -187,21 +205,23 @@ class TorrentParser(object):
         # correspondingly.
         try:
             self.parsed_content = bencode.bdecode(self.torrent_content)
-        except BTL.BTFailure as bterr:
-            logging.debug(
-                'bencode.bdecode failed: ({0}); \
-                trying alternate approach'.format(bterr))
+        except bencode.BTFailure as bterr:
+            logging.info(
+                'bencode.bdecode failed: ({0});'
+                'trying alternate approach'.format(bterr))
             self.torrent_str = self._TorrentStr(self.torrent_content)
             self.parsed_content = self._parse_torrent()
 
+        # print('parsed content: {}'.format(self.parsed_content))
+
     def get_tracker_url(self):
         """
         Retrieves tracker URL from the parsed torrent file
 
-        :returns:   tracker URL from parased torrent file
+        :returns:   tracker URL from parsed torrent file
         :rtype:     str
         """
-        return self.parsed_content.get('announce')
+        return self.parsed_content.get(b'announce')
 
     def get_creation_date(self, time_format='iso'):
         """
@@ -213,7 +233,7 @@ class TorrentParser(object):
         :returns:               creation date
         :rtype:                 datetime
         """
-        time_stamp = self.parsed_content.get('creation date')
+        time_stamp = self.parsed_content.get(b'creation date')
         if time_stamp:
             time_stamp = datetime.utcfromtimestamp(time_stamp)
 
@@ -230,7 +250,7 @@ class TorrentParser(object):
         :returns:   name of the client that created the torrent
         :rtype:     str
         """
-        return self.parsed_content.get('created by')
+        return self.parsed_content.get(b'created by')
 
     def get_files_details(self):
         """
@@ -246,24 +266,30 @@ class TorrentParser(object):
         :rtype:     list of tuples (name, length, checksum)
         """
         parsed_files_info = []
-        files_info = self.parsed_content.get('info')
+        files_info = self.parsed_content.get(b'info')
         # 'info' should be present in all torrent files. Nevertheless..
         if files_info:
-            multiple_files_info = files_info.get('files')
+            multiple_files_info = files_info.get(b'files')
+            logging.debug('files: |{}|'.format(multiple_files_info))
             if multiple_files_info:  # multiple-file torrent
                 # the name attribute was holding the directory name that each
                 # of the multiple files were contained within.
-                dir_name = files_info.get('name')
+                dir_name = files_info.get(b'name').decode(encoding='utf-8')
+                logging.debug('dirname: |{}|'.format(dir_name))
                 for file_info in multiple_files_info:
+                    logging.debug('file_info: |{}|'.format(file_info))
                     # simply append the directory to the concatenated list
                     # of items under path, mostly it is a single item.
                     parsed_files_info.append(
                         (os.path.join(dir_name,
-                                      os.path.sep.join(file_info.get('path'))),
-                         file_info.get('length'),))
+                                      os.path.sep.join(
+                                          [x.decode(encoding='utf-8') for x in
+                                           file_info.get(b'path')])),
+                         file_info.get(b'length'),))
             else:  # single file torrent
-                parsed_files_info.append((files_info.get('name'),
-                                          files_info.get('length'), ))
+                parsed_files_info.append(
+                    (files_info.get(b'name').decode(encoding='utf-8'),
+                     files_info.get(b'length'), ))
 
         return parsed_files_info
 
@@ -287,7 +313,7 @@ class TorrentParser(object):
         elif parsed_char == self.INT_START:
             return self.torrent_str.parse_int()
 
-        elif parsed_char in string.digits:  # string
+        elif _is_int(parsed_char):  # string
             self.torrent_str.step_back()
             return self.torrent_str.parse_str()
 
@@ -298,7 +324,11 @@ class TorrentParser(object):
                 if not dict_key:
                     break  # End of dict
                 dict_value = self._parse_torrent()  # parse value
-                parsed_dict.setdefault(dict_key, dict_value)
+                if isinstance(dict_value, six.binary_type):
+                    dict_value = dict_value.decode(encoding='utf-8',
+                                                   errors='replace')
+                parsed_dict.setdefault(dict_key.decode(encoding='utf-8'),
+                                       dict_value)
 
             return parsed_dict
 
@@ -308,6 +338,10 @@ class TorrentParser(object):
                 list_item = self._parse_torrent()
                 if not list_item:
                     break  # End of list
+
+                if isinstance(list_item, six.binary_type):
+                    list_item = list_item.decode(encoding='utf-8',
+                                                 errors='replace')
                 parsed_list.append(list_item)
 
             return parsed_list
